==> jc-1.4.0.tar.gz: soot/jimple/toolkits/invoke/SiteInliner.h <==
// public class soot.jimple.toolkits.invoke.SiteInliner

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 49a5078995c08c32 soot_jimple_toolkits_invoke_SiteInliner

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_invoke_SiteInliner_H_
#define _JC_soot_jimple_toolkits_invoke_SiteInliner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_refs	_jc_soot_jimple_toolkits_invoke_SiteInliner$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_SiteInliner$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_SiteInliner$refs	_jc_soot_jimple_toolkits_invoke_SiteInliner$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_SiteInliner$nonrefs	_jc_soot_jimple_toolkits_invoke_SiteInliner$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_SiteInliner$object	_jc_soot_jimple_toolkits_invoke_SiteInliner$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vmethods	_jc_soot_jimple_toolkits_invoke_SiteInliner$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vtable	_jc_soot_jimple_toolkits_invoke_SiteInliner$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vtype	_jc_soot_jimple_toolkits_invoke_SiteInliner$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_SiteInliner$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SiteInliner$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_invoke_SiteInliner$method$getDefaultOptions$2203c46727b257b7(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SiteInliner$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_invoke_SiteInliner$method_info$getDefaultOptions$2203c46727b257b7;

// Static methods
extern void _jc_soot_jimple_toolkits_invoke_SiteInliner$method$inlineSite$525cf76ae613d1bb(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *);
extern void _jc_soot_jimple_toolkits_invoke_SiteInliner$method$inlineSite$af237dbb9c05612e(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_invoke_SiteInliner$method$inlineSites$0a0f24ae142d1833(_jc_env *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_invoke_SiteInliner$method$inlineSites$d78e84505dbf599a(_jc_env *, struct _jc_object *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vmethods {
	struct _jc_java_lang_String$object	*(*getDefaultOptions$2203c46727b257b7)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SiteInliner$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_invoke_SiteInliner$vmethods	soot_jimple_toolkits_invoke_SiteInliner;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_SiteInliner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$refs {
    _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_refs	soot_jimple_toolkits_invoke_SiteInliner;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_nonrefs	soot_jimple_toolkits_invoke_SiteInliner;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$object {
	_jc_soot_jimple_toolkits_invoke_SiteInliner$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_SiteInliner$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_SiteInliner$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_SiteInliner$vtype _jc_soot_jimple_toolkits_invoke_SiteInliner$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_SiteInliner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_SiteInliner$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_SiteInliner_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/invoke/SiteInliner.h <==
// public class soot.jimple.toolkits.invoke.SiteInliner

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 49a5078995c08c32 soot_jimple_toolkits_invoke_SiteInliner

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_invoke_SiteInliner_H_
#define _JC_soot_jimple_toolkits_invoke_SiteInliner_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_refs	_jc_soot_jimple_toolkits_invoke_SiteInliner$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_SiteInliner$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_SiteInliner$refs	_jc_soot_jimple_toolkits_invoke_SiteInliner$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_SiteInliner$nonrefs	_jc_soot_jimple_toolkits_invoke_SiteInliner$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_SiteInliner$object	_jc_soot_jimple_toolkits_invoke_SiteInliner$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vmethods	_jc_soot_jimple_toolkits_invoke_SiteInliner$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vtable	_jc_soot_jimple_toolkits_invoke_SiteInliner$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vtype	_jc_soot_jimple_toolkits_invoke_SiteInliner$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_SiteInliner$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SiteInliner$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_invoke_SiteInliner$method$getDefaultOptions$2203c46727b257b7(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SiteInliner$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_invoke_SiteInliner$method_info$getDefaultOptions$2203c46727b257b7;

// Static methods
extern void _jc_soot_jimple_toolkits_invoke_SiteInliner$method$inlineSite$525cf76ae613d1bb(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_invoke_SiteInliner$method$inlineSite$af237dbb9c05612e(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_invoke_SiteInliner$method$inlineSites$0a0f24ae142d1833(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_invoke_SiteInliner$method$inlineSites$d78e84505dbf599a(_jc_env *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vmethods {
	struct _jc_java_lang_String$object	*(*getDefaultOptions$2203c46727b257b7)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_SiteInliner$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_invoke_SiteInliner$vmethods	soot_jimple_toolkits_invoke_SiteInliner;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_SiteInliner$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$refs {
    _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_refs	soot_jimple_toolkits_invoke_SiteInliner;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_invoke_SiteInliner$sub_nonrefs	soot_jimple_toolkits_invoke_SiteInliner;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_SiteInliner$object {
	_jc_soot_jimple_toolkits_invoke_SiteInliner$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_SiteInliner$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_SiteInliner$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_SiteInliner$vtype _jc_soot_jimple_toolkits_invoke_SiteInliner$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_SiteInliner, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_SiteInliner$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_SiteInliner_H_ */
